@@ -20,6 +20,7 @@ from .types import (
     StoryLink,
     StoryMedia,
     StoryMention,
+    Track,
     User,
     UserShort,
     Usertag,
@@ -294,11 +295,13 @@ def extract_account(data):
 
 def extract_hashtag_gql(data):
     data["media_count"] = data.get("edge_hashtag_to_media", {}).get("count")
+    data["profile_pic_url"] = data["profile_pic_url"] or None
     return Hashtag(**data)
 
 
 def extract_hashtag_v1(data):
     data["allow_following"] = data.get("allow_following") == 1
+    data["profile_pic_url"] = data["profile_pic_url"] or None
     return Hashtag(**data)
 
 
@@ -384,3 +387,7 @@ def extract_highlight_v1(data):
         for item in highlight['items']
     ]
     return Highlight(**highlight)
+
+
+def extract_track(data):
+    return Track(**data)
